==> dnet-mapreduce-jobs-0.0.2-20140417.161426-112-sources.jar: eu/dnetlib/data/mapreduce/util/UpdateMerger.java <==
package eu.dnetlib.data.mapreduce.util;

import java.util.Collections;
import java.util.List;
import java.util.Map;

import org.apache.hadoop.hbase.util.Bytes;
import org.apache.hadoop.mapreduce.Mapper.Context;

import com.google.common.collect.Lists;
import com.google.protobuf.InvalidProtocolBufferException;

import eu.dnetlib.data.proto.OafProtos.Oaf;

public class UpdateMerger {

	private static final String UPDATE_MERGER = "UPDATE_MERGE";
	private static final String N_MERGES = "N_MERGES";

	@SuppressWarnings("rawtypes")
	public static Oaf mergeBodyUpdates(final Context context, final Map<byte[], byte[]> map) throws InvalidProtocolBufferException {
		byte[] value = map.get(Bytes.toBytes("body"));
		if (value == null) { return null; }
		Oaf.Builder builder = Oaf.newBuilder(Oaf.parseFrom(value));
		final List<String> keys = Lists.newArrayList();

		// we fetch all the body updates
		for (byte[] o : map.keySet()) {
			final String sKey = Bytes.toString(o);
			if (sKey.startsWith("update_")) {
				keys.add(sKey);
			}
		}

		// we merge all the sorted updates with the body
		Collections.sort(keys);
		for (String k : keys) {
			Oaf update = Oaf.parseFrom(map.get(Bytes.toBytes(k)));
			// System.out.println("\n\nBODY: \n" + body.build().toString());
			// System.out.println("UPDATE: \n" + update.toString());
			builder = builder.mergeFrom(update);
			// System.out.println("UDPATED BODY: \n" + body.build().toString() + "\n\n");
		}

		new OafEntityMerger().doMergeEntities(builder);

		if (!keys.isEmpty()) {
			context.getCounter(UPDATE_MERGER, N_MERGES).increment(keys.size());
		}
		return builder.build();
	}

}

==> dnet-mapreduce-jobs-0.0.4.1-20141022.083047-21-sources.jar: eu/dnetlib/data/mapreduce/util/UpdateMerger.java <==
package eu.dnetlib.data.mapreduce.util;

import java.util.Collections;
import java.util.List;
import java.util.Map;

import org.apache.hadoop.hbase.util.Bytes;
import org.apache.hadoop.mapreduce.Mapper.Context;

import com.google.common.collect.Lists;
import com.google.protobuf.InvalidProtocolBufferException;

import eu.dnetlib.data.proto.OafProtos.Oaf;

public class UpdateMerger {

	private static final String UPDATE_MERGER = "UPDATE_MERGE";
	private static final String N_MERGES = "N_MERGES";

	@SuppressWarnings("rawtypes")
	public static Oaf mergeBodyUpdates(final Context context, final Map<byte[], byte[]> map) throws InvalidProtocolBufferException {
		byte[] value = map.get(DedupUtils.BODY_B);
		if (value == null) return null;

		Oaf.Builder builder = Oaf.newBuilder(Oaf.parseFrom(value));
		final List<String> keys = Lists.newArrayList();

		// we fetch all the body updates
		for (byte[] o : map.keySet()) {
			final String sKey = Bytes.toString(o);
			if (sKey.startsWith("update_")) {
				keys.add(sKey);
			}
		}
		if (!keys.isEmpty()) {
			// we merge all the sorted updates with the body
			Collections.sort(keys);
			for (String k : keys) {
				Oaf update = Oaf.parseFrom(map.get(Bytes.toBytes(k)));
				// System.out.println("\n\nBODY: \n" + body.build().toString());
				// System.out.println("UPDATE: \n" + update.toString());
				builder.mergeFrom(update);
				// System.out.println("UDPATED BODY: \n" + body.build().toString() + "\n\n");
			}

			builder = OafEntityMerger.merge(builder);

			context.getCounter(UPDATE_MERGER, N_MERGES).increment(keys.size());
		}
		return builder.build();
	}

}
